@@ -4,11 +4,11 @@ davies <- function(q,lambda,h = rep(1,length(lambda)),delta = rep(0,length(lambd
   if (length(h) != r) stop("lambda and h should have the same length!")
   if (length(delta) != r) stop("lambda and delta should have the same length!")
   
-  out <- .C("qfc",lambdas=as.double(lambda),noncentral=as.double(delta),df=as.integer(h),r=as.integer(r),sigma=as.double(sigma),q=as.double(q),lim=as.integer(lim),acc=as.double(acc),trace=as.double(rep(0,7)),ifault=as.double(0),res=as.double(0),PACKAGE="CompQuadForm")
+  out <- .C("qfc",lambdas=as.double(lambda),noncentral=as.double(delta),df=as.integer(h),r=as.integer(r),sigma=as.double(sigma),q=as.double(q),lim=as.integer(lim),acc=as.double(acc),trace=as.double(rep(0,7)),ifault=as.integer(0),res=as.double(0),PACKAGE="CompQuadForm")
 
   out$res <- 1 - out$res
   
-  return(out)
+  return(list(trace=out$trace,ifault=out$ifault,Qq=out$res))
   
 }
 
